# 012

|                                                      | Asko hood 1         |
|:-----------------------------------------------------|:--------------------|
| bindTime                                             | 1711489190532       |
| createTime                                           | 0                   |
| deviceFeatureCode                                    | 000                 |
| deviceFeatureName                                    | ConnectlifeHOOD     |
| deviceId                                             | <redacted>          |
| deviceNickName                                       | Hood                |
| deviceTypeCode                                       | 012                 |
| deviceTypeName                                       |                     |
| offlineState                                         | 1                   |
| puid                                                 | <redacted>          |
| role                                                 | 1                   |
| roomId                                               | 142500              |
| roomName                                             | AR kitchen          |
| seq                                                  | 0                   |
| statusList.ActiveModeLightBrightness                 | 0                   |
| statusList.ActiveModeLightColorTemperature           | 0                   |
| statusList.ActiveModeLightStatus                     | 2                   |
| statusList.ActiveModeMotorLevel                      | 1                   |
| statusList.ActiveModeMotorLevelStatus                | 2                   |
| statusList.ActiveModeStatus                          | 2                   |
| statusList.AlarmCleanAirEnded                        | 1                   |
| statusList.AlarmGreaseFilter                         | 1                   |
| statusList.AlarmRecirculationFilter1                 | 1                   |
| statusList.AlarmRecirculationFilter2                 | 1                   |
| statusList.AlarmTimerEnded                           | 1                   |
| statusList.AmbientLightBrightness                    | 0                   |
| statusList.AmbientLightColorTemperature              | 0                   |
| statusList.AmbientLightStatus                        | 0                   |
| statusList.CirculationModeStatus                     | 1                   |
| statusList.CleanAirActivePassedHours                 | 0                   |
| statusList.CleanAirActiveTotalHours                  | 24                  |
| statusList.CleanAirDurationOfCycleInMinutes          | 10                  |
| statusList.CleanAirMotorLevel                        | 1                   |
| statusList.CleanAirRunCycleEveryNumberOfMinutes      | 0                   |
| statusList.CleanAirStartTime                         | 0002/11/30T00:00:00 |
| statusList.CleanAirStatus                            | 1                   |
| statusList.DeviceStatus                              | 1                   |
| statusList.FotaStatus                                | 0                   |
| statusList.GreaseFilterCleaningIntervalInHours       | 30                  |
| statusList.GreaseFilterStatus                        | 2                   |
| statusList.GreaseFilterUsedHours                     | 23                  |
| statusList.HardPairingStatus                         | 0                   |
| statusList.LightBrightness                           | 75                  |
| statusList.LightColorTemperature                     | 49                  |
| statusList.LightStatus                               | 1                   |
| statusList.MotorLevel                                | 0                   |
| statusList.ProximitySensor                           | 2                   |
| statusList.ProximitySensorReactionTime               | 0                   |
| statusList.ProximitySensorSensitivity                | 0                   |
| statusList.ProximitySensorStatus                     | 2                   |
| statusList.RFPairingStatus                           | 0                   |
| statusList.RecirculationFilter1LifetimeInHours       | 360                 |
| statusList.RecirculationFilter1Status                | 1                   |
| statusList.RecirculationFilter1Type                  | 4                   |
| statusList.RecirculationFilter1UsedHours             | 0                   |
| statusList.RecirculationFilter2LifetimeInHours       | 0                   |
| statusList.RecirculationFilter2Status                | 1                   |
| statusList.RecirculationFilter2Type                  | 1                   |
| statusList.RecirculationFilter2UsedHours             | 0                   |
| statusList.RemoteControlMonitoringSetCommands        | 2                   |
| statusList.RemoteControlMonitoringSetCommandsActions | 0                   |
| statusList.SessionPairing                            | 0                   |
| statusList.SessionPairingActive                      | 0                   |
| statusList.SessionPairingConfirmation                | 0                   |
| statusList.SoftPairing                               | 0                   |
| statusList.TimerEndTime                              | 0002/11/30T00:00:00 |
| statusList.TimerPausedTime                           | 0002/11/30T00:00:00 |
| statusList.TimerPausedTotalSeconds                   | 0                   |
| statusList.TimerStartTime                            | 0002/11/30T00:00:00 |
| statusList.TimerStatus                               | 1                   |
| statusList.daily_energy_kwh                          | 0                   |
| useTime                                              | 0                   |
| wifiId                                               | <redacted>          |

## Generated from

- [`Asko_hood_1.json`](Asko_hood_1.json)
